@@ -312,7 +312,7 @@ def get_object_s3(obj_key: str, bucket: str, s3: botocore.client.BaseClient = No
         try:
             if isinstance(public_url, str):
                 url = b2_public_key_pattern.format(base_url=public_url.rstrip('/'), bucket=bucket, obj_key=obj_key)
-                resp = requests.get(url)
+                resp = requests.get(url, timeout=300)
                 resp.raise_for_status()
 
                 ts_obj = resp.content
@@ -595,7 +595,7 @@ def url_stream_to_file(url, file_path, compression=None, chunk_size=524288):
     counter = 4
     while True:
         try:
-            with requests.get(url, stream=True) as r:
+            with requests.get(url, stream=True, timeout=300) as r:
                 r.raise_for_status()
                 stream = ResponseStream(r.iter_content(chunk_size))
 
@@ -713,6 +713,28 @@ def get_results_chunk(dataset_id, station_id, remote, version):
     return stn_dict
 
 
+def load_dataset(results, from_date=None, to_date=None):
+    """
+
+    """
+    if isinstance(results, (pathlib.Path, str)):
+        data = xr.load_dataset(results)
+    else:
+        data = results
+
+    if isinstance(from_date, (str, pd.Timestamp, datetime)):
+        from_date1 = pd.Timestamp(from_date)
+    else:
+        from_date1 = None
+    if isinstance(to_date, (str, pd.Timestamp, datetime)):
+        to_date1 = pd.Timestamp(to_date)
+    else:
+        to_date1 = None
+
+    if (to_date1 is not None) or (from_date1 is not None):
+        data = data.sel(time=slice(from_date1, to_date1))
+
+    return data
 
 
 
